==> xl-react-components-0.16.62.tgz: package/app/xl-react-widget/xl-react-widget-tags/xl-react-widget-tags-service.js <==
import R from 'ramda';
import {transformItem, transformModel} from '../../utils/transform-utils';
import {
    checkboxSuggestionBehavior,
    colorAndCheckboxSuggestionBehavior
} from './suggestion-behavior/skin-suggestion-behavior';

export const inputTypes = {
    AUTOCOMPLETE: 'autocomplete',
    TEXT: 'text'
};

export const hasSearchedTerm = R.curry((objLabel, queryString, suggestion) =>
    R.toLower(transformItem(suggestion, objLabel)).includes(R.toLower(queryString)));

export const sortItems = (objLabel, filteredItems) => R.sort(
    (item1, item2) => String(transformItem(item1, objLabel)).localeCompare(String(transformItem(item2, objLabel))),
    filteredItems
);

export const toggleChecked = R.curry((model, objLabel, suggestion) =>
    R.assoc('checked', R.is(Object, R.find(R.propEq('value', suggestion[objLabel]))(model)))(suggestion));

export const filterSuggestionsByValue = R.curry((model, objLabel, suggestions) => {
    const value = transformModel('value', model);
    return R.filter((suggestion) => !R.includes(suggestion[objLabel], value), suggestions);
});

export const valueToModel = (value) => ({
    label: value,
    value
});

export const keepOrRemoveColor = (modelItem) => R.ifElse(
    R.propIs(String, 'color'),
    R.identity,
    R.omit(['color'])
)(modelItem);

export const suggestionToModel = R.curry((tagTransform, objLabel, suggestion) => keepOrRemoveColor({
    color: suggestion.color,
    label: tagTransform(transformItem(suggestion, objLabel)),
    value: transformItem(suggestion, objLabel)
}));

export const selectRemainingSuggestions = (objLabel, model, suggestions, tagTransform) => R.pipe(
    filterSuggestionsByValue(model, objLabel),
    R.map(suggestionToModel(tagTransform, objLabel))
)(suggestions);

export const appendNewSuggestion = (item, model, objLabel, tagTransform) =>
    R.append(suggestionToModel(tagTransform, objLabel, item))(model);

export const removeExistingSuggestion = (item, model, objLabel) =>
    R.without(R.filter(R.propEq('value', transformItem(item, objLabel)))(model))(model);

export const transformModelForInputTags = (valuesList) => {
    const lastItem = valuesList[valuesList.length - 1];
    if (R.is(String, lastItem)) {
        valuesList[valuesList.length - 1] = {
            label: lastItem,
            value: lastItem
        };
    }
    return valuesList;
};

export const getIndex = (item, suggestions, objLabel) =>
    R.findIndex(R.propEq(objLabel, item[objLabel]))(suggestions);

export const getItemsToSelect = (startIndex, stopIndex, suggestions) => {
    if (stopIndex > startIndex) {
        return R.slice(
            R.inc(startIndex),
            R.inc(stopIndex),
            suggestions
        );
    } else if (stopIndex < startIndex) {
        return R.slice(
            R.negate(startIndex),
            R.or(R.negate(stopIndex), Infinity),
            R.reverse(suggestions)
        );
    }
    return [suggestions[stopIndex]];
};

export const getSuggestionBehavior = (skin) =>
    R.find(
        (sb) => sb.isMatched(skin),
        [checkboxSuggestionBehavior, colorAndCheckboxSuggestionBehavior]
    );

==> xl-react-components-0.21.12.tgz: package/app/xl-react-widget/xl-react-widget-tags/xl-react-widget-tags-service.js <==
import R from 'ramda';
import {transformItem, transformModel} from '../../utils/transform-utils';
import {
    checkboxSuggestionBehavior,
    colorAndCheckboxSuggestionBehavior
} from './suggestion-behavior/skin-suggestion-behavior';

export const inputTypes = {
    AUTOCOMPLETE: 'autocomplete',
    TEXT: 'text'
};

export const hasSearchedTerm = R.curry((objLabel, queryString, suggestion) =>
    R.toLower(transformItem(suggestion, objLabel)).includes(R.toLower(queryString)));

export const sortItems = (objLabel, visibleItems) => R.sort(
    (item1, item2) => String(transformItem(item1, objLabel)).localeCompare(String(transformItem(item2, objLabel))),
    visibleItems
);

export const toggleChecked = R.curry((model, objLabel, suggestion) =>
    R.assoc('checked', R.is(Object, R.find(R.propEq('value', suggestion[objLabel]))(model)))(suggestion));

export const filterSuggestionsByValue = R.curry((model, objLabel, suggestions) => {
    const value = transformModel('value', model);
    return R.filter((suggestion) => !R.includes(suggestion[objLabel], value), suggestions);
});

export const valueToModel = (value) => ({
    label: value,
    value
});

export const keepOrRemoveColor = (modelItem) => R.ifElse(
    R.propIs(String, 'color'),
    R.identity,
    R.omit(['color'])
)(modelItem);

export const suggestionToModel = R.curry((tagTransform, objLabel, suggestion) => keepOrRemoveColor({
    color: suggestion.color,
    label: tagTransform(transformItem(suggestion, objLabel)),
    value: transformItem(suggestion, objLabel)
}));

export const selectRemainingSuggestions = (objLabel, model, suggestions, tagTransform) => R.pipe(
    filterSuggestionsByValue(model, objLabel),
    R.map(suggestionToModel(tagTransform, objLabel))
)(suggestions);

export const appendNewSuggestion = (item, model, objLabel, tagTransform) =>
    R.append(suggestionToModel(tagTransform, objLabel, item))(model);

export const removeExistingSuggestion = (item, model, objLabel) =>
    R.without(R.filter(R.propEq('value', transformItem(item, objLabel)))(model))(model);

export const transformModelForInputTags = (valuesList) => {
    const lastItem = valuesList[valuesList.length - 1];
    if (R.is(String, lastItem)) {
        valuesList[valuesList.length - 1] = {
            label: lastItem,
            value: lastItem
        };
    }
    return valuesList;
};

export const getIndex = (item, suggestions, objLabel) =>
    R.findIndex(R.propEq(objLabel, item[objLabel]))(suggestions);

export const getItemsToSelect = (startIndex, stopIndex, suggestions) => {
    if (stopIndex > startIndex) {
        return R.slice(
            R.inc(startIndex),
            R.inc(stopIndex),
            suggestions
        );
    } else if (stopIndex < startIndex) {
        return R.slice(
            R.negate(startIndex),
            R.or(R.negate(stopIndex), Infinity),
            R.reverse(suggestions)
        );
    }
    return [suggestions[stopIndex]];
};

export const getSuggestionBehavior = (skin) =>
    R.find(
        (sb) => sb.isMatched(skin),
        [checkboxSuggestionBehavior, colorAndCheckboxSuggestionBehavior]
    );
